/*********************************************************************/
/* tclparse V2.00 from 14.March 1997                                 */
/* Copyright 1996/97 Stephan Weiss, Heiko Grossmann                  */
/*                   University of Stuttgart, Germany                */
/* For details see the copyright file included in the distribution.  */
/* This notice must not be removed from the file.                    */
/*                                                                   */
/* main source of the tclparse program                               */
/*                                                                   */
/*********************************************************************/

#include <iostream.h>
#include <stdlib.h> 
#include "../include/display.h"
#include "../include/parsing.h"


int main( int argc, char *argv[] )
{
  //Eine Startmeldung ausgeben.
  display.Title( "TCLPARSE: parse a tcl program file for syntactical errors" );

  //Fehler: Es wurde kein Dateiname angegeben.
  if( argc == 1 )
    {
      cout << "error: there was no filename specified\n\n"
	   << "synopsis: parse  file1.tcl  ? options ?\n\n"
	   << "options:\n"
	   << "\t-c, -commands        : show command names\n"
	   << "\t-i, -infofile <file> : load alternative information file\n"
	   << "\t-nc, -nocode         : show no program code\n"
	   << "\t-ne, -noerrors       : show no error messages\n"
	   << "\t-nw, -nowarnings     : show no warning messages\n"
	   << "\t-p, -procedures      : show procedure names\n"
	   << "\t-tcl                 : only accept tcl commands, no tk commands\n"
	   << "\t-v, -variables       : show variable names\n"
	   << "\t-w, -widgets         : show widget names\n\n";

      exit( 0 );
    }

  //Die Schalter auswerten, wenn vorhanden. 'argv[ 1 ]' ist der Name der
  //zu bearbeitenden Datei, darum beim Index '2' beginnen.
  if( argc > 2 )
    {
      for( int i=2 ; i < argc ; i++ )
	{
	  if( IsElementOf( argv[ i ], " -c -commands " ) )
	    flag.commands = 1;

	  else if( IsElementOf( argv[ i ], " -i -infofile " ) )
	    {
	      i++;
	      if( i >= argc )
		{
		  cout << "no alternative information file specified after '" << argv[ i-1 ] << "'\n\n";
		  exit( 0 );
		}
	      flag.infoFile = new char[ strlen( argv[ i ] )+1 ];
	      strcpy( flag.infoFile, argv[ i ] );
	    }

	  else if( IsElementOf( argv[ i ], " -nc -nocode " ) )
	    flag.code = 0;

	  else if( IsElementOf( argv[ i ], " -ne -noerrors " ) )
	    flag.errors = 0;

	  else if( IsElementOf( argv[ i ], " -nw -nowarnings " ) )
	    flag.warnings = 0;

	  else if( IsElementOf( argv[ i ], " -p -procedures " ) )
	    flag.procedures = 1;

	  else if( !strcmp( argv[ i ], "-tcl" ) )
	    flag.tclmode = 1;

	  else if( IsElementOf( argv[ i ], " -v -variables " ) )
	    flag.variables = 1;

	  else if( IsElementOf( argv[ i ], " -w -widgets " ) )
	    flag.widgets = 1;

	  else
	    {
	      cout << "unknown option: '" << argv[ i ] << "'\n\n";
	      exit( 0 );
	    }
	}
    }

  //Die Datei bearbeiten.
  ParseFile( argv[ 1 ] );
}
